@@ -44,7 +44,7 @@ dropdown_ <- function(..., class = NULL) {
 #' @noRd
 #'
 #' @importFrom htmltools tags tagList HTML
-#' @importFrom shiny icon checkboxInput
+#' @importFrom shiny checkboxInput
 #' @importFrom datamods filter_data_ui
 #'
 controls_ui <- function(id,
@@ -54,7 +54,7 @@ controls_ui <- function(id,
   if (!is.null(controls)) {
     controls <- match.arg(
       controls,
-      choices = c("labs", "parameters", "appearance", "filters", "code"), 
+      choices = c("labs", "parameters", "appearance", "filters", "code"),
       several.ok = TRUE
     )
   } else {
@@ -70,7 +70,7 @@ controls_ui <- function(id,
   disable_filters <- !"filters" %in% controls
   if (isTRUE(disable_filters))
     controls <- setdiff(controls, "filters")
-  
+
   tagList(
     tags$div(
       class = "btn-group-esquisse btn-group-justified-esquisse",
@@ -80,9 +80,9 @@ controls_ui <- function(id,
           inputId = ns("controls-labs"),
           class = "esquisse-controls-labs",
           style = "default",
-          label = "Labels & Title",
+          label = i18n("Labels & Title"),
           up = TRUE,
-          icon = icon("font"),
+          icon = ph("text-aa"),
           status = "default btn-esquisse-controls"
         )
       },
@@ -92,9 +92,9 @@ controls_ui <- function(id,
           inputId = ns("controls-parameters"),
           class = "esquisse-controls-parameters",
           style = "default",
-          label = "Plot options",
+          label = i18n("Plot options"),
           up = TRUE,
-          icon = icon("gears"),
+          icon = ph("gear"),
           status = "default btn-esquisse-controls"
         )
       },
@@ -104,9 +104,9 @@ controls_ui <- function(id,
           inputId = ns("controls-appearance"),
           class = "esquisse-controls-appearance",
           style = "default",
-          label = "Appearance",
+          label = i18n("Appearance"),
           up = TRUE,
-          icon = icon("palette"),
+          icon = ph("palette"),
           status = "default btn-esquisse-controls"
         )
       },
@@ -116,9 +116,9 @@ controls_ui <- function(id,
           inputId = ns("controls-filters"),
           class = "esquisse-controls-filters",
           style = "default",
-          label = "Data",
+          label = i18n("Data"),
           up = TRUE,
-          icon = icon("filter"),
+          icon = ph("sliders-horizontal"),
           status = "default btn-esquisse-controls"
         )
       },
@@ -128,10 +128,10 @@ controls_ui <- function(id,
           inputId = ns("controls-code"),
           class = "esquisse-controls-code",
           style = "default",
-          label = "Code",
+          label = i18n("Code"),
           up = TRUE,
           right = TRUE,
-          icon = icon("code"),
+          icon = ph("code"),
           status = "default btn-esquisse-controls"
         )
       }
@@ -186,10 +186,10 @@ controls_server <- function(id,
                             use_transY = reactive(FALSE)) {
 
   callModule(
-    id = id, 
+    id = id,
     module = function(input, output, session) {
       ns <- session$ns
-      
+
       # Reset labs ----
       observeEvent(data_table(), {
         updateTextInput(session = session, inputId = "labs_title", value = character(0))
@@ -224,7 +224,7 @@ controls_server <- function(id,
         }
         rstudioapi::insertText(text = paste0("\n", code, "\n"), id = context$id)
       })
-      
+
       output$code <- renderUI({
         code <- style_code(ggplot_rv$code)
         expr <- output_filter$expr()
@@ -238,11 +238,11 @@ controls_server <- function(id,
           rCodeContainer(id = ns("codeggplot"), code)
         )
       })
-      
-      
-      
+
+
+
       # Controls ----
-      
+
       observeEvent(aesthetics(), {
         aesthetics <- names(aesthetics())
         toggleDisplay(id = ns("controls-labs-fill"), display = "fill" %in% aesthetics)
@@ -251,29 +251,29 @@ controls_server <- function(id,
         toggleDisplay(id = ns("controls-labs-shape"), display = "shape" %in% aesthetics)
         toggleDisplay(id = ns("controls-ribbon-color"), display = "ymin" %in% aesthetics)
       })
-      
+
       observeEvent(use_facet(), {
         toggleDisplay(id = ns("controls-facet"), display = isTRUE(use_facet()))
       })
-      
+
       observeEvent(use_transX(), {
         toggleDisplay(id = ns("controls-scale-trans-x"), display = isTRUE(use_transX()))
       })
-      
+
       observeEvent(use_transY(), {
         toggleDisplay(id = ns("controls-scale-trans-y"), display = isTRUE(use_transY()))
       })
-      
+
       observeEvent(type$palette, {
         toggleDisplay(id = ns("controls-palette"), display = isTRUE(type$palette))
         toggleDisplay(id = ns("controls-fill-color"), display = !isTRUE(type$palette))
       })
-      
+
       observe({
         aesthetics <- names(aesthetics())
         toggleDisplay(id = ns("controls-shape"), display = type$x %in% "point" & !"shape" %in% aesthetics)
       })
-      
+
       observeEvent(type$x, {
         toggleDisplay(id = ns("controls-position"), display = type$x %in% c("bar", "line", "area"))
         toggleDisplay(id = ns("controls-histogram"), display = type$x %in% "histogram")
@@ -281,14 +281,15 @@ controls_server <- function(id,
         toggleDisplay(id = ns("controls-scatter"), display = type$x %in% "point")
         toggleDisplay(id = ns("controls-size"), display = type$x %in% c("point", "line", "step", "sf"))
         toggleDisplay(id = ns("controls-violin"), display = type$x %in% "violin")
-        
+        toggleDisplay(id = ns("controls-jitter"), display = type$x %in% c("boxplot", "violin"))
+
         if (type$x %in% c("point")) {
           updateSliderInput(session = session, inputId = "size", value = 1.5)
         } else if (type$x %in% c("line", "step")) {
           updateSliderInput(session = session, inputId = "size", value = 0.5)
         }
       })
-      
+
       output_filter <- filter_data_server(
         id = "filter-data",
         data = reactive({
@@ -302,18 +303,18 @@ controls_server <- function(id,
         }),
         name = data_name
       )
-      
+
       outputs <- reactiveValues(
         inputs = NULL,
         export_ppt = NULL,
         export_png = NULL
       )
-      
+
       observeEvent(data_table(), {
         outputs$data <- data_table()
         outputs$code <- reactiveValues(expr = NULL, dplyr = NULL)
       })
-      
+
       observeEvent({
         all_inputs <- reactiveValuesToList(input)
         all_inputs[grep(pattern = "filter-data", x = names(all_inputs), invert = TRUE)]
@@ -324,9 +325,13 @@ controls_server <- function(id,
         inputs <- inputs[grep(pattern = "^labs_", x = names(inputs), invert = TRUE)]
         inputs <- inputs[grep(pattern = "^export_", x = names(inputs), invert = TRUE)]
         inputs <- inputs[order(names(inputs))]
+        aesthetics <- names(aesthetics())
+        if (!(type$x %in% "point" & !"shape" %in% aesthetics)) {
+          inputs$shape <- NULL
+        }
         outputs$inputs <- inputs
       })
-      
+
       # labs input
       labs_r <- debounce(reactive({
         asth <- names(aesthetics())
@@ -349,7 +354,7 @@ controls_server <- function(id,
       observe({
         outputs$labs <- labs_r()
       })
-      
+
       # Colors input
       colors_r <- palette_server("colors", reactive({
         data_ <- data_table()
@@ -366,8 +371,8 @@ controls_server <- function(id,
       observe({
         outputs$colors <- colors_r_d()
       })
-      
-      
+
+
       # limits input
       observe({
         outputs$limits <- list(
@@ -377,8 +382,8 @@ controls_server <- function(id,
           ylim = input$ylim
         )
       })
-      
-      
+
+
       # facet input
       observe({
         outputs$facet <- list(
@@ -395,7 +400,7 @@ controls_server <- function(id,
           }
         )
       })
-      
+
       # theme input
       observe({
         inputs <- reactiveValuesToList(input)
@@ -418,12 +423,12 @@ controls_server <- function(id,
           )
         )
       })
-      
+
       # coord input
       observe({
         outputs$coord <- if (isTRUE(input$flip)) "flip" else NULL
       })
-      
+
       # smooth input
       observe({
         outputs$smooth <- list(
@@ -434,6 +439,14 @@ controls_server <- function(id,
         )
       })
       
+      # jittered input
+      observe({
+        outputs$jitter <- list(
+          add = input$jitter_add,
+          args = list()
+        )
+      })
+
       # transX input
       observe({
         outputs$transX <- list(
@@ -443,7 +456,7 @@ controls_server <- function(id,
           )
         )
       })
-      
+
       # transY input
       observe({
         outputs$transY <- list(
@@ -453,14 +466,14 @@ controls_server <- function(id,
           )
         )
       })
-      
+
       observeEvent(output_filter$filtered(), {
         if (!isTRUE(input$disable_filters)) {
           outputs$data <- output_filter$filtered()
           outputs$code <- output_filter$code()
         }
       })
-      
+
       return(outputs)
     }
   )
@@ -481,61 +494,61 @@ controls_labs <- function(ns) {
   tags$div(
     class = "form-group",
     labs_options_input(
-      inputId = ns("labs_title"), 
-      placeholder = "Title", 
-      label = "Title:",
+      inputId = ns("labs_title"),
+      placeholder = i18n("Title"),
+      label = i18n("Title:"),
       defaults = get_labs_defaults("title")
     ),
     labs_options_input(
-      inputId = ns("labs_subtitle"), 
-      placeholder = "Subtitle",
-      label = "Subtitle:",
+      inputId = ns("labs_subtitle"),
+      placeholder = i18n("Subtitle"),
+      label = i18n("Subtitle:"),
       defaults = get_labs_defaults("subtitle")
     ),
     labs_options_input(
-      inputId = ns("labs_caption"), 
-      placeholder = "Caption",
-      label = "Caption:",
+      inputId = ns("labs_caption"),
+      placeholder = i18n("Caption"),
+      label = i18n("Caption:"),
       defaults = get_labs_defaults("caption")
     ),
     labs_options_input(
-      inputId = ns("labs_x"), 
-      placeholder = "X label", 
-      label = "X label:",
+      inputId = ns("labs_x"),
+      placeholder = i18n("X label"),
+      label = i18n("X label:"),
       defaults = get_labs_defaults("x")
     ),
     labs_options_input(
       inputId = ns("labs_y"),
-      placeholder = "Y label", 
-      label = "Y label:",
+      placeholder = i18n("Y label"),
+      label = i18n("Y label:"),
       defaults = get_labs_defaults("y")
     ),
     tags$div(
-      id = ns("controls-labs-fill"), 
+      id = ns("controls-labs-fill"),
       style = "display: none;",
-      textInput(inputId = ns("labs_fill"), placeholder = "Fill label", label = "Fill label:")
+      textInput(inputId = ns("labs_fill"), placeholder = i18n("Fill label"), label = i18n("Fill label:"))
     ),
     tags$div(
-      id = ns("controls-labs-color"), 
+      id = ns("controls-labs-color"),
       style = "display: none;",
-      textInput(inputId = ns("labs_color"), placeholder = "Color label", label = "Color label:")
+      textInput(inputId = ns("labs_color"), placeholder = i18n("Color label"), label = i18n("Color label:"))
     ),
     tags$div(
-      id = ns("controls-labs-size"), 
+      id = ns("controls-labs-size"),
       style = "display: none;",
-      textInput(inputId = ns("labs_size"), placeholder = "Size label", label = "Size label:")
+      textInput(inputId = ns("labs_size"), placeholder = i18n("Size label"), label = i18n("Size label:"))
     ),
     tags$div(
-      id = ns("controls-labs-shape"), 
+      id = ns("controls-labs-shape"),
       style = "display: none;",
-      textInput(inputId = ns("labs_shape"), placeholder = "Shape label", label = "Shape label:")
+      textInput(inputId = ns("labs_shape"), placeholder = i18n("Shape label"), label = i18n("Shape label:"))
     )
   )
 }
 
 #' @importFrom htmltools tags
 #' @importFrom shinyWidgets dropMenu prettyRadioButtons
-#' @importFrom shiny actionButton icon numericInput
+#' @importFrom shiny actionButton numericInput
 labs_options_input <- function(inputId, label, placeholder, defaults = list()) {
   tags$div(
     class = "esquisse-labs-options",
@@ -544,13 +557,13 @@ labs_options_input <- function(inputId, label, placeholder, defaults = list()) {
       style = "width: 100%;",
       tags$label(
         class = "control-label",
-        id = paste0(inputId, "-label"), 
+        id = paste0(inputId, "-label"),
         `for` = inputId,
         label
       ),
       tags$input(
         id = inputId,
-        type = "text", 
+        type = "text",
         class = "form-control",
         value = "",
         placeholder = placeholder,
@@ -559,15 +572,14 @@ labs_options_input <- function(inputId, label, placeholder, defaults = list()) {
     ),
     dropMenu(
       actionButton(
-        inputId = paste0(inputId, "_options"), 
-        label = NULL, 
-        icon = icon("plus"),
+        inputId = paste0(inputId, "_options"),
+        label = ph("plus"),
         style = "margin-top: 25px; border-radius: 0 4px 4px 0; width: 100%;"
       ),
       style = "width: 320px;",
       prettyRadioButtons(
         inputId = paste0(inputId, "_face"),
-        label = "Font face:",
+        label = i18n("Font face:"),
         choiceNames = c("Plain", "Italic", "Bold", "Bold/Italic"),
         choiceValues = c("plain", "italic", "bold", "bold.italic"),
         selected = defaults$face,
@@ -576,13 +588,13 @@ labs_options_input <- function(inputId, label, placeholder, defaults = list()) {
       ),
       numericInput(
         inputId = paste0(inputId, "_size"),
-        label = "Font size:",
+        label = i18n("Font size:"),
         value = defaults$size
       ),
       prettyRadioButtons(
         inputId = paste0(inputId, "_align"),
-        label = "Align:",
-        choiceNames = c("Left", "Center", "Right"),
+        label = i18n("Align:"),
+        choiceNames = c(i18n("Left"), i18n("Center"), i18n("Right")),
         choiceValues = c("left", "center", "right"),
         inline = TRUE,
         status = "primary",
@@ -648,9 +660,8 @@ get_labs_options <- function(inputs, name = c("title", "subtitle", "caption", "x
 #' @param ns Namespace from module
 #'
 #' @noRd
-#' 
+#'
 #' @importFrom utils head
-#' @importFrom shiny icon
 #' @importFrom htmltools tagList tags
 #' @importFrom shinyWidgets pickerInput radioGroupButtons colorPickr
 controls_appearance <- function(ns) {
@@ -658,7 +669,7 @@ controls_appearance <- function(ns) {
   themes <- get_themes()
   cols <- get_colors()
   pals <- get_palettes()
-  
+
   shape_names <- c(
     "circle", paste("circle", c("open", "filled", "cross", "plus", "small")), "bullet",
     "square", paste("square", c("open", "filled", "cross", "plus", "triangle")),
@@ -673,7 +684,7 @@ controls_appearance <- function(ns) {
       id = ns("controls-fill-color"), style = "display: block;",
       shinyWidgets::colorPickr(
         inputId = ns("fill_color"),
-        label = "Color:",
+        label = i18n("Color:"),
         theme = "monolith",
         update = "changestop",
         inline = TRUE,
@@ -698,7 +709,7 @@ controls_appearance <- function(ns) {
       colorPickr(
         inputId = ns("color_ribbon"),
         selected = "#A4A4A4",
-        label = "Ribbon color:",
+        label = i18n("Ribbon color:"),
         theme = "nano",
         useAsButton = TRUE,
         update = "save",
@@ -715,7 +726,7 @@ controls_appearance <- function(ns) {
       id = ns("controls-shape"), style = "display: none;",
       pickerInput(
         inputId = ns("shape"),
-        label = "Point symbol:",
+        label = i18n("Point symbol:"),
         choices = shape_names,
         selected = "circle",
         options = list(size = 10, container = "body"),
@@ -724,7 +735,7 @@ controls_appearance <- function(ns) {
     ),
     pickerInput(
       inputId = ns("theme"),
-      label = "Theme:",
+      label = i18n("Theme:"),
       choices = themes,
       selected = getOption("esquisse.default.theme", default = "theme_minimal"),
       options = list(size = 10, container = "body"),
@@ -735,10 +746,13 @@ controls_appearance <- function(ns) {
     ),
     radioGroupButtons(
       inputId = ns("legend_position"),
-      label = "Legend position:",
+      label = i18n("Legend position:"),
       choiceNames = list(
-        icon("arrow-left"), icon("arrow-up"),
-        icon("arrow-down"), icon("arrow-right"), icon("close")
+        ph("arrow-left"),
+        ph("arrow-up"),
+        ph("arrow-down"),
+        ph("arrow-right"),
+        ph("x")
       ),
       choiceValues = c("left", "top", "bottom", "right", "none"),
       selected = "right",
@@ -777,16 +791,14 @@ controls_params <- function(ns) {
       tags$label(
         class = "control-label",
         `for` = ns("smooth_add"),
-        "Add a smooth line:"
+        i18n("Add a smooth line:")
       ),
       prettyToggle(
         inputId = ns("smooth_add"),
-        label_on = "Yes",
-        icon_on = icon("check"),
+        label_on = i18n("Yes"),
         status_on = "success",
         status_off = "danger",
-        label_off = "No",
-        icon_off = icon("remove"),
+        label_off = i18n("No"),
         inline = TRUE
       ),
       conditionalPanel(
@@ -794,21 +806,38 @@ controls_params <- function(ns) {
         ns = ns,
         sliderInput(
           inputId = ns("smooth_span"),
-          label = "Smooth line span:",
-          min = 0.1, 
+          label = i18n("Smooth line span:"),
+          min = 0.1,
           max = 1,
-          value = 0.75, 
+          value = 0.75,
           step = 0.01,
           width = "100%"
         )
       ),
     ),
+    tags$div(
+      id = ns("controls-jitter"),
+      style = "display: none; padding-top: 10px;",
+      tags$label(
+        class = "control-label",
+        `for` = ns("jitter_add"),
+        i18n("Jittered points:")
+      ),
+      prettyToggle(
+        inputId = ns("jitter_add"),
+        label_on = i18n("Yes"),
+        status_on = "success",
+        status_off = "danger",
+        label_off = i18n("No"),
+        inline = TRUE
+      )
+    ),
     tags$div(
       id = ns("controls-size"), style = "display: none;",
       sliderInput(
         inputId = ns("size"),
-        label = "Size for points/lines:",
-        min = 0.5, 
+        label = i18n("Size for points/lines:"),
+        min = 0.5,
         max = 4,
         value = 1.2,
         width = "100%"
@@ -818,32 +847,36 @@ controls_params <- function(ns) {
       id = ns("controls-facet"), style = "display: none;",
       prettyRadioButtons(
         inputId = ns("facet_scales"),
-        label = "Facet scales:",
+        label = i18n("Facet scales:"),
         inline = TRUE,
         status = "primary",
         choices = c("fixed", "free", "free_x", "free_y"),
-        outline = TRUE,
-        icon = icon("check")
+        outline = TRUE
       ),
       sliderInput(
         inputId = ns("facet_ncol"),
-        label = "Facet ncol:",
-        min = 0, max = 10,
-        value = 0, step = 1
+        label = i18n("Facet ncol:"),
+        min = 0,
+        max = 10,
+        value = 0,
+        step = 1
       ),
       sliderInput(
         inputId = ns("facet_nrow"),
-        label = "Facet nrow:",
-        min = 0, max = 10,
-        value = 0, step = 1
+        label = i18n("Facet nrow:"),
+        min = 0,
+        max = 10,
+        value = 0,
+        step = 1
       )
     ),
     tags$div(
       id = ns("controls-histogram"), style = "display: none;",
       sliderInput(
         inputId = ns("bins"),
-        label = "Numbers of bins:",
-        min = 10, max = 100,
+        label = i18n("Numbers of bins:"),
+        min = 10,
+        max = 100,
         value = 30,
         width = "100%"
       )
@@ -852,24 +885,23 @@ controls_params <- function(ns) {
       id = ns("controls-violin"), style = "display: none;",
       prettyRadioButtons(
         inputId = ns("scale"),
-        label = "Scale:",
+        label = i18n("Scale:"),
         inline = TRUE,
         status = "primary",
         choices = c("area", "count", "width"),
-        outline = TRUE,
-        icon = icon("check")
+        outline = TRUE
       )
     ),
     tags$div(
       id = ns("controls-scale-trans-x"), style = "display: none;",
       numericRangeInput(
         inputId = ns("xlim"),
-        label = "X-Axis limits (empty for none):",
+        label = i18n("X-Axis limits (empty for none):"),
         value = c(NA, NA)
       ),
       selectInput(
         inputId = ns("transX"),
-        label = "X-Axis transform:",
+        label = i18n("X-Axis transform:"),
         selected = "identity",
         choices = scales_trans,
         width = "100%"
@@ -879,12 +911,12 @@ controls_params <- function(ns) {
       id = ns("controls-scale-trans-y"), style = "display: none;",
       numericRangeInput(
         inputId = ns("ylim"),
-        label = "Y-Axis limits (empty for none):",
+        label = i18n("Y-Axis limits (empty for none):"),
         value = c(NA, NA)
       ),
       selectInput(
         inputId = ns("transY"),
-        label = "Y-Axis transform:",
+        label = i18n("Y-Axis transform:"),
         selected = "identity",
         choices = scales_trans,
         width = "100%"
@@ -895,7 +927,7 @@ controls_params <- function(ns) {
       style = "display: none;",
       sliderInput(
         inputId = ns("adjust"),
-        label = "Bandwidth adjustment:",
+        label = i18n("Bandwidth adjustment:"),
         min = 0.2,
         max = 6,
         value = 1,
@@ -908,7 +940,7 @@ controls_params <- function(ns) {
       style = "display: none;",
       prettyRadioButtons(
         inputId = ns("position"),
-        label = "Position:",
+        label = i18n("Position:"),
         choices = c("stack", "dodge", "fill"),
         inline = TRUE,
         selected = "stack",
@@ -919,16 +951,14 @@ controls_params <- function(ns) {
     tags$label(
       class = "control-label",
       `for` = ns("flip"),
-      "Flip coordinate:"
+      i18n("Flip coordinate:")
     ),
     prettyToggle(
       inputId = ns("flip"),
-      label_on = "Yes",
-      icon_on = icon("check"),
+      label_on = i18n("Yes"),
       status_on = "success",
       status_off = "danger",
-      label_off = "No",
-      icon_off = icon("remove"),
+      label_off = i18n("No"),
       inline = TRUE
     )
   )
@@ -942,24 +972,24 @@ controls_params <- function(ns) {
 #' @param ns Namespace from module
 #'
 #' @noRd
-#' @importFrom shiny icon downloadButton uiOutput actionLink
+#' @importFrom shiny downloadButton uiOutput actionLink
 #' @importFrom htmltools tagList tags
 #'
 controls_code <- function(ns, insert_code = FALSE) {
   tagList(
     tags$button(
       class = "btn btn-default btn-xs pull-right btn-copy-code",
-      "Copy to clipboard", `data-clipboard-target` = paste0("#", ns("codeggplot"))
+      i18n("Copy to clipboard"),
+      `data-clipboard-target` = paste0("#", ns("codeggplot"))
     ), tags$script("$(function() {new ClipboardJS('.btn-copy-code');});"),
     tags$br(),
-    tags$b("Code:"),
+    tags$b(i18n("Code:")),
     uiOutput(outputId = ns("code")),
     tags$textarea(id = ns("holderCode"), style = "display: none;"),
     if (insert_code) {
       actionLink(
         inputId = ns("insert_code"),
-        label = "Insert code in script",
-        icon = icon("arrow-circle-left")
+        label = tagList(ph("arrow-circle-left"), i18n("Insert code in script"))
       )
     },
     tags$br()
@@ -989,6 +1019,8 @@ select_geom_controls <- function(x, geoms) {
     "area"
   } else if ("violin" %in% geoms & x %in% c("violin")) {
     "violin"
+  } else if ("boxplot" %in% geoms & x %in% c("boxplot")) {
+    "boxplot"
   } else if ("sf" %in% geoms & x %in% c("sf")) {
     "sf"
   } else {
